@@ -48,7 +48,7 @@ def open_database(
         return maxminddb.extension.Reader(database)
     if mode in (MODE_AUTO, MODE_MMAP, MODE_FILE, MODE_MEMORY, MODE_FD):
         return PyReader(database, mode)
-    raise ValueError("Unsupported open mode: {0}".format(mode))
+    raise ValueError(f"Unsupported open mode: {mode}")
 
 
 def Reader(database):  # pylint: disable=invalid-name
@@ -57,7 +57,7 @@ def Reader(database):  # pylint: disable=invalid-name
 
 
 __title__ = "maxminddb"
-__version__ = "2.0.0"
+__version__ = "2.1.0"
 __author__ = "Gregory Oschwald"
 __license__ = "Apache License, Version 2.0"
 __copyright__ = "Copyright 2013-2020 MaxMind, Inc."
