@@ -3,6 +3,7 @@
 
 import ipaddress
 import os
+import pathlib
 import threading
 import unittest
 import unittest.mock as mock
@@ -78,7 +79,12 @@ class BaseTestReader(object):
             "double": 42.123456,
             "float": 1.100000023841858,
             "int32": -268435456,
-            "map": {"mapX": {"arrayX": [7, 8, 9], "utf8_stringX": "hello",},},
+            "map": {
+                "mapX": {
+                    "arrayX": [7, 8, 9],
+                    "utf8_stringX": "hello",
+                },
+            },
             "uint128": 1329227995784915872903807060280344576,
             "uint16": 0x64,
             "uint32": 0x10000000,
@@ -170,12 +176,8 @@ class BaseTestReader(object):
                 self.assertEqual(
                     prefix_len,
                     test["expected_prefix_len"],
-                    "expected prefix_len of {} for {} in {} but got {}".format(
-                        test["expected_prefix_len"],
-                        test["ip"],
-                        test["file_name"],
-                        prefix_len,
-                    ),
+                    f"expected prefix_len of {test['expected_prefix_len']} for {test['ip']}"
+                    + f" in {test['file_name']} but got {prefix_len}",
                 )
                 self.assertEqual(
                     record,
@@ -196,7 +198,10 @@ class BaseTestReader(object):
         self.assertAlmostEqual(record["float"], 1.1)
         self.assertEqual(record["int32"], -268435456)
         self.assertEqual(
-            {"mapX": {"arrayX": [7, 8, 9], "utf8_stringX": "hello"},}, record["map"]
+            {
+                "mapX": {"arrayX": [7, 8, 9], "utf8_stringX": "hello"},
+            },
+            record["map"],
         )
 
         self.assertEqual(record["uint16"], 100)
@@ -207,6 +212,15 @@ class BaseTestReader(object):
         self.assertEqual(1329227995784915872903807060280344576, record["uint128"])
         reader.close()
 
+    def test_metadata_pointers(self):
+        with open_database(
+            "tests/data/test-data/MaxMind-DB-test-metadata-pointers.mmdb", self.mode
+        ) as reader:
+            self.assertEqual(
+                "Lots of pointers in metadata",
+                reader.metadata().database_type,
+            )
+
     def test_no_ipv4_search_tree(self):
         reader = open_database(
             "tests/data/test-data/MaxMind-DB-no-ipv4-search-tree.mmdb", self.mode
@@ -229,6 +243,12 @@ class BaseTestReader(object):
             reader.get(self.ipf("2001::"))
         reader.close()
 
+    def test_opening_path(self):
+        with open_database(
+            pathlib.Path("tests/data/test-data/MaxMind-DB-test-decoder.mmdb"), self.mode
+        ) as reader:
+            self.assertEqual(reader.metadata().database_type, "MaxMind DB Decoder Test")
+
     def test_no_extension_exception(self):
         real_extension = maxminddb.extension
         maxminddb.extension = None
@@ -434,7 +454,7 @@ class BaseTestReader(object):
         def lookup(pipe):
             try:
                 for i in range(32):
-                    reader.get(self.ipf("65.115.240.{i}".format(i=i)))
+                    reader.get(self.ipf(f"65.115.240.{i}"))
                 pipe.send(1)
             except:
                 pipe.send(0)
